<?php

namespace Modules\Sd\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Sd\Entities\VesselAvailability;
use Modules\Sd\Entities\VesselAvailabilityAttachment;
use Modules\Sd\Entities\VesselSchedule;
use Modules\Sd\Entities\VesselScheduleAttachment;
use Modules\St\Entities\Currency;

class VesselScheduledController extends Controller
{
    public function getScheduleData()
    {
        try {
            $query = 'SELECT * FROM sd_vessel_schedules ORDER BY `created_at` DESC';
            $schedules = DB::select($query);
            $result = array();

            foreach ($schedules as $schedule) {
                array_push($result, [
                    "factory_order_no" => $schedule->factory_order_no,
                    "eta" => $schedule->eta,
                    "customer_po" => $schedule->customer_po,
                    "designation" => $schedule->designation,
                    "cargo_ready_date" => $schedule->cargo_ready_date,
                    "suggest_vessel" => $schedule->suggest_vessel,
                    "suggest_date" => $schedule->suggest_date,
                    "shipping_rate" => $schedule->shipping_rate,
                    "created_at" => $schedule->created_at,
                    "updated_at" => $schedule->updated_at,
                ]);
            }
            $responseBody = $this->responseBody(true, "VesselScheduledController", "getScheduleData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "getScheduleData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getCurrencyPrimaryID()
    {
        try {
            $query = 'SELECT currency_id,iso_code  FROM st_currencies WHERE `status` = 1';
            $currencies = DB::select($query);
            $result = array();

            foreach ($currencies as $currency) {
                array_push($result, [
                    "currency_id" => $currency->currency_id,
                    "currency_code" => $currency->iso_code,
                ]);
            }

            $responseBody = $this->responseBody(true, "VesselScheduledController", "getCurrencyData", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "getCurrencyData", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    public function getScheduleHeader($id)
    {
        try {
            $query = 'SELECT pp_customer_orders.factory_po_num,
            st_customer_deliveries.address,
            pp_customer_orders.purchase_order,
            pp_customer_orders.delivery_date
            FROM pp_customer_orders
            LEFT JOIN st_customer_deliveries ON pp_customer_orders.customer_id = st_customer_deliveries.customer_id
            WHERE pp_customer_orders.order_id = "' . $id . '"';
            $result = DB::select($query)[0];
            if ($result) {
                $result->currency = Currency::all();
            }

            $responseBody = $this->responseBody(true, "VesselScheduledController", "getScheduleHeader", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "getScheduleHeader", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function uploadScheduleAttachment(Request $request)
    {

        $description = $request->get('foo');
        $token = $request->get('attachmnet_token');
        $file = $request->file('file');
        $file_name = $file->getClientOriginalName();
        $filename = 'http://127.0.0.1:8000/order/' . uniqid() . '_' . time() . '.' . str_replace(' ', '_', $file_name);
        //$filename = 'https://erp.rbs.lk/order/' . uniqid() . '_' . time() . '.' .str_replace(' ', '_', $file_name);
        $file->move(public_path('order'), $filename);

        $vessel_attachment = new VesselScheduleAttachment();
        $vessel_attachment->vessel_schedule_attachment_id = 0;
        $vessel_attachment->description = $description;
        $vessel_attachment->file_path = $filename;
        $vessel_attachment->token = $token;
        return $vessel_attachment->save();
    }



    public function allScheduleAttachment($id)
    {
        try {

            $attachment = DB::select('SELECT * FROM sd_vessel_schedule_attachments WHERE  vessel_schedule_id = "' . $id . '" OR vessel_schedule_id = "0"');
            $responseBody = $this->responseBody(true, "VesselScheduledController", "allVesselAttachment", $attachment);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "allVesselAttachment", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function saveSchedule(Request $request)
    {
        try {
            VesselSchedule::where('order_id', '=', $request->get('order_id'))->delete();
            $vesselSchedule = new VesselSchedule();
            $vesselSchedule->factory_order_no = $request->get('factory_order_no');
            $vesselSchedule->eta = $request->get('eta');
            $vesselSchedule->customer_po = $request->get('customer_po');
            $vesselSchedule->designation = $request->get('designation');
            $vesselSchedule->cargo_ready_date = $request->get('cargo_ready_date');
            $vesselSchedule->suggest_vessel = $request->get('suggest_vessel');
            $vesselSchedule->suggest_date = $request->get('suggest_date');
            $vesselSchedule->shipping_rate = $request->get('shipping_rate');
            $vesselSchedule->currency_id = $request->get('currency_id');
            $vesselSchedule->order_id = $request->get('order_id');
            if ($vesselSchedule->save()) {
                $attachments = VesselScheduleAttachment::where([['vessel_schedule_id', '=', 0], ['token', '=', $request->token]])->get();
                foreach ($attachments as $attachment) {
                    $attachment->vessel_schedule_id = $vesselSchedule->vessel_schedule_id;
                    $attachment->update();
                }
                $attachments = VesselScheduleAttachment::where('token', '=', $request->token)->get();
                foreach ($attachments as $attachment) {
                    $attachment->vessel_schedule_id = $vesselSchedule->vessel_schedule_id;
                    $attachment->update();
                }
            }

            $responseBody = $this->responseBody(true, "VesselScheduledController", "saveSchedule", $request->token);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "saveSchedule", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    public function load_saved_schedule($id)
    {
        try {
            $schedule = VesselSchedule::where('order_id', '=', $id)->first();
            $schedule->current_schedule = false;
            if ($schedule) {
                $schedule->attachment = VesselScheduleAttachment::where('vessel_schedule_id', '=', $schedule->vessel_schedule_id)->get();
                $schedule->current_schedule = true;
            }
            $responseBody = $this->responseBody(true, "VesselScheduledController", "load_saved_schedule", $schedule);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "load_saved_schedule", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getFactoryOrderNo()
    {
        try {
            $query = "SELECT
            *
        FROM
            pp_customer_orders 
        WHERE
            production_status = '1' 
        OR 
            production_status = '2'";
            $orders = DB::select($query);
            $result = array();

            foreach ($orders as $order) {
                array_push($result, [
                    "factory_po_num" => $order->factory_po_num,
                ]);
            }


            $responseBody = $this->responseBody(true, "VesselScheduledController", "getFactoryOrderNo", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getCustomerOrderData($id)
    {
        try {
            $query = "SELECT  
            purchase_order,delivery_address,delivery_date,order_id,factory_po_num
            FROM 
                pp_customer_orders 
            WHERE 
                factory_po_num = {$id}";
            $orders = DB::select($query);
            $result = array();

            foreach ($orders as $order) {
                array_push($result, [
                    "purchase_order" => $order->purchase_order,
                    "delivery_address" => $order->delivery_address,
                    "delivery_date" => $order->delivery_date,
                    "order_id" => $order->order_id,
                    "factory_order_no" => $order->factory_po_num
                ]);
            }


            $responseBody = $this->responseBody(true, "VesselScheduledController", "getCustomerOrderData", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "VesselScheduledController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}