<?php

use Illuminate\Support\Facades\Route;
use Modules\Sd\Http\Controllers\CustomerOrderController;
use Modules\Sd\Http\Controllers\CustomerOrderListController;
use Modules\Sd\Http\Controllers\CustomerOrderStatusListController;
use Modules\Sd\Http\Controllers\CustomerOrderThreadController;
use Modules\Sd\Http\Controllers\SvrController;
use Modules\Sd\Http\Controllers\VesselAvailabilityController;
use Modules\Sd\Http\Controllers\VesselScheduledController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::prefix('sd')->group(function () {

    Route::get('/dashboard', function () {
        return view('sd::dashboard');
    })->middleware('is.logged');

    Route::get('/orderList', function () {
        return view('sd::orderList');
    })->middleware('is.logged');


    Route::get('/customerOrder', function () {
        return view('sd::customerOrder');
    })->middleware('is.logged');

    Route::get('/orderStatusList', function () {
        return view('sd::orderStatusList');
    })->middleware('is.logged');

    Route::get('/vesselSchedule', function () {
        return view('sd::vesselSchedule');
    })->middleware('is.logged');

    Route::get('/vesselScheduleList', function () {
        return view('sd::vesselScheduleList');
    })->middleware('is.logged');
    
    /** svrController */
    Route::get('/svr/date', [SvrController::class, 'serverDate']);
    /** End svrController */

    /** Customer Order List Controller */
    Route::get('/customerOrderList/allCustomerOrder/{year}/{month}', [CustomerOrderListController::class, 'allCustomerOrder']);
   
    Route::post('/customerOrderList/uploadAvailabilityAttachment', [VesselAvailabilityController::class, 'uploadAvailabilityAttachment']);
    Route::get('/customerOrderList/allAvailabilityAttachment/{id}', [VesselAvailabilityController::class, 'allAvailabilityAttachment']);
    Route::get('/customerOrderList/getAvailabilityHeader/{id}', [VesselAvailabilityController::class, 'getAvailabilityHeader']);
    Route::post('/customerOrderList/saveAvailability', [VesselAvailabilityController::class, 'saveAvailability']);
    Route::get('/customerOrderList/load_saved_availability/{id}', [VesselAvailabilityController::class, 'load_saved_availability']);



    Route::post('/customerOrderList/uploadScheduleAttachment', [VesselScheduledController::class, 'uploadScheduleAttachment']);
    Route::get('/customerOrderList/allScheduleAttachment/{id}', [VesselScheduledController::class, 'allScheduleAttachment']);
    Route::get('/customerOrderList/getScheduleHeader/{id}', [VesselScheduledController::class, 'getScheduleHeader']);
    Route::post('/customerOrderList/saveSchedule', [VesselScheduledController::class, 'saveSchedule']);
    Route::get('/customerOrderList/load_saved_schedule/{id}', [VesselScheduledController::class, 'load_saved_schedule']);
    /** End Of Customer Order List Controller */


    /** Customer Order Status List Controller */
    Route::get('/CustomerOrderStatusListController/allCustomerOrder/{year}/{month}', [CustomerOrderStatusListController::class, 'allCustomerOrder']);
    Route::post('/CustomerOrderStatusListController/shipping_status', [CustomerOrderStatusListController::class, 'shipping_status']);
    /** End Of Customer Order Status List Controller */



    /** Customer Order */
    Route::get('/customerOrder/allCustomer', [CustomerOrderController::class, 'allCustomers']);
    Route::get('/customerOrder/getCustomer/{id}', [CustomerOrderController::class, 'SelectedCustomersData']);
    Route::get('/customerOrder/allCountries', [CustomerOrderController::class, 'allCountries']);
    Route::get('/customerOrder/allShippingTerms', [CustomerOrderController::class, 'allShippingTerms']);
    Route::get('/customerOrder/allDrainHoleSize', [CustomerOrderController::class, 'allDrainHoleSize']);
    Route::get('/customerOrder/allDrainHoleShape', [CustomerOrderController::class, 'allDrainHoleShape']);
    Route::get('/customerOrder/allProductMix', [CustomerOrderController::class, 'allProductMix']);
    Route::get('/customerOrder/allWashedLevel', [CustomerOrderController::class, 'allWashedLevel']);
    Route::get('/customerOrder/allOrderDataWithToken/{id}/{token}/{action}', [CustomerOrderController::class, 'allOrderDataWithToken']);
    Route::get('/customerOrder/allOrderData/{id}', [CustomerOrderController::class, 'allOrderData']);
    Route::get('/customerOrder/getCustomerAllOrderData/{id}', [CustomerOrderController::class, 'getCustomerAllOrderData']);
    Route::get('/customerOrder/getCustomerOrderData/{id}', [CustomerOrderController::class, 'getCustomerOrderData']);
    Route::get('/customerOrder/getCustomerMainOrder/{id}', [CustomerOrderController::class, 'getCustomerMainOrder']);
    Route::get('/customerOrder/allAttachment/{id}', [CustomerOrderController::class, 'allAttachment']);
    Route::get('/customerOrder/allAttachmentEditViewMode/{id}', [CustomerOrderController::class, 'allAttachmentEditViewMode']);
    Route::post('/customerOrder/saveOrderData', [CustomerOrderController::class, 'saveOrderData']);
    Route::post('/customerOrder/updateOrderData/{id}', [CustomerOrderController::class, 'updateOrderData']);
    Route::post('/customerOrder/saveCustomerOrder', [CustomerOrderController::class, 'saveCustomerOrder']);
    Route::post('/customerOrder/updateCustomerOrder/{id}', [CustomerOrderController::class, 'updateCustomerOrder']);

    Route::delete('/customerOrder/deleteOrderData/{id}', [CustomerOrderController::class, 'deleteOrderData']);
    Route::delete('/customerOrder/deleteAttachment/{id}', [CustomerOrderController::class, 'deleteAttachment']);
    Route::post('/customerOrder/uploadAttachment', [CustomerOrderController::class, 'uploadAttachment']);
    Route::get('/customerOrder/checkOrderStatus/{id}', [CustomerOrderController::class, 'checkOrderStatus']);
    Route::get('/customerOrder/customerAllDeliveryAddress/{id}', [CustomerOrderController::class, 'customerAllDeliveryAddress']);
    Route::get('/customerOrder/isDuplicateFactoryPO/{id}', [CustomerOrderController::class, 'isDuplicateFactoryPO']);
    Route::post('/customerOrder/saveAttachmentViewOrder', [CustomerOrderController::class, 'saveAttachmentViewOrder']);
    /** End Customer Order */


    /** Customer Order Thread */
    Route::post('/customerOrderThread/submit', [CustomerOrderThreadController::class, 'submit']);
    Route::get('/customerOrderThread/loadCustomerOrderThread/{order_id}', [CustomerOrderThreadController::class, 'loadCustomerOrderThread']);
    /** End of Customer Order Thread  */


    /** Vessel Schedule */
    Route::get('/VesselScheduledController/getFactoryOrderNo', [VesselScheduledController::class, 'getFactoryOrderNo']);
    Route::get('/VesselScheduledController/getCustomerOrderData/{id}', [VesselScheduledController::class, 'getCustomerOrderData']);
    Route::post('/VesselScheduled/saveSchedule', [VesselScheduledController::class, 'saveSchedule']);
    Route::get('/vesselSchedule/allSchedule', [VesselScheduledController::class, 'getScheduleData']);
    Route::get('/VesselSchedule/getCurrencyPrimaryID', [VesselScheduledController::class, 'getCurrencyPrimaryID']);
    /** End of Vessel Schedule  */
});
